@@ -200,6 +200,7 @@ Interruptible(observer, 0)
     mHeight = 40;
     type = ACTION_SPELL;
     cost = NEW ManaCost();
+    cost->extraCosts = NULL;
     tc = NULL;
     from = _source->getCurrentZone();
     payResult = ManaCost::MANA_UNPAID;
@@ -209,7 +210,11 @@ Interruptible(observer, 0)
 Spell::Spell(GameObserver* observer, int id, MTGCardInstance * _source, TargetChooser * tc, ManaCost * _cost, int payResult) :
 Interruptible(observer, id), tc(tc), cost(_cost), payResult(payResult)
 {
-    if (!cost) cost = NEW ManaCost();
+    if (!cost)
+    {
+        cost = NEW ManaCost();
+        cost->extraCosts = NULL;
+    }
     source = _source;
     mHeight = 40;
     type = ACTION_SPELL;
@@ -287,29 +292,28 @@ Spell::~Spell()
 
 int Spell::resolve()
 {
-    if (!source->hasType(Subtypes::TYPE_INSTANT) && !source->hasType(Subtypes::TYPE_SORCERY))
+    MTGCardInstance * oldStored = source->storedCard;
+    if (!source->hasType(Subtypes::TYPE_INSTANT) && !source->hasType(Subtypes::TYPE_SORCERY) && source->name.size())
     {
         Player * p = source->controller();
         int castMethod = source->castMethod;
+        vector<Targetable*>backupTgt = source->backupTargets;
         source = p->game->putInZone(source, from, p->game->battlefield);
         
         // We need to get the information about the cast method on both the card in the stack AND the card in play,
         //so we copy it from the previous card (in the stack) to the new one (in play).
         source->castMethod = castMethod; 
-
+        source->backupTargets = backupTgt;
         from = p->game->battlefield;
     }
-
+    source->storedCard = oldStored;
     //Play SFX
     if (options[Options::SFXVOLUME].number > 0)
     {
-        JSample * sample = source->getSample();
-        if (sample)
-        {
-            JSoundSystem::GetInstance()->PlaySample(sample);
-        }
-    }
 
+		if(observer->getResourceManager())
+			observer->getResourceManager()->PlaySample(source->getSample());
+    }
     AbilityFactory af(observer);
     af.addAbilities(observer->mLayers->actionLayer()->getMaxId(), this);
     return 1;
@@ -835,7 +839,8 @@ void ActionStack::Update(float dt)
 {
     //This is a hack to avoid updating the stack while tuto messages are being shown
     //Ideally, the tuto messages should be moved to a layer above this one
-    if (getCurrentTutorial())
+    //No need for Tuto when no human in game
+    if (getCurrentTutorial() && (observer->players[0]->isHuman() || observer->players[1]->isHuman() ) )
         return;
 
     askIfWishesToInterrupt = NULL;
@@ -968,8 +973,11 @@ void ActionStack::cancelInterruptOffer(InterruptDecision cancelMode, bool log)
     askIfWishesToInterrupt = NULL;
     observer->isInterrupting = NULL;
     timer = -1;
-    if(log)
-        observer->logAction(playerId, "no");
+    if(log) {
+        stringstream stream;
+        stream << "no " << cancelMode;
+        observer->logAction(playerId, stream.str());
+    }
 }
 
 void ActionStack::endOfInterruption(bool log)
