@@ -5,7 +5,10 @@
 #include "GameObserver.h"
 #include "Rules.h"
 
-GuiBackground::GuiBackground()
+const std::string kBackdropFile = "backdrop.jpg";
+
+GuiBackground::GuiBackground(GameObserver* observer)
+    : GuiLayer(observer)
 {
 }
 
@@ -17,14 +20,13 @@ void GuiBackground::Render()
 {
     JRenderer* renderer = JRenderer::GetInstance();
     JQuadPtr quad;
-    GameObserver * go = GameObserver::GetInstance();
-    if (go && go->mRules && go->mRules->bg.size())
+    if (observer && observer->mRules && observer->mRules->bg.size())
     {
-        quad = WResourceManager::Instance()->RetrieveTempQuad(go->mRules->bg);
+        quad = WResourceManager::Instance()->RetrieveTempQuad(observer->mRules->bg);
     }
     if (!quad.get())
     {
-        quad = WResourceManager::Instance()->RetrieveTempQuad("backdrop.jpg");
+        quad = WResourceManager::Instance()->RetrieveTempQuad(kBackdropFile);
     }
     if (quad.get())
     {
